@@ -25,7 +25,7 @@
                           + QString("/../Resources")
 #else
 #define USER_DIR        QDir::homePath() + QString("/.gpxsee")
-#define GLOBAL_DIR      QString("/opt/usr/share/gpxsee")
+#define GLOBAL_DIR      QString("/opt/gpxsee/usr/share/gpxsee")
 #endif
 
 #define USER_MAP_FILE   USER_DIR + QString("/") + MAP_FILE
