@@ -1,5 +1,9 @@
 #include <QFile>
 #include <QFileInfo>
+#if defined (Q_WS_MAEMO_5)
+#include <QSslSocket>
+#include <QSslConfiguration>
+#endif
 #include "config.h"
 #include "downloader.h"
 
@@ -40,20 +44,23 @@ bool Downloader::doDownload(const Download &dl, const Redirect &redirect)
 	if (_currentDownloads.contains(url))
 		return false;
 
-    /*if (url.toString().contains("https"))
-    {
-
-    }*/
-	QNetworkRequest request(url);
-	request.setAttribute(ATTR_FILE, QVariant(dl.file()));
-	if (!redirect.isNull()) {
-		request.setAttribute(ATTR_ORIGIN, QVariant(redirect.origin()));
-		request.setAttribute(ATTR_LEVEL, QVariant(redirect.level()));
-	}
-	request.setRawHeader("User-Agent", USER_AGENT);
-	QNetworkReply *reply = _manager.get(request);
-
-	_currentDownloads.insert(url, reply);
+        QNetworkRequest request(url);
+        request.setAttribute(ATTR_FILE, QVariant(dl.file()));
+        if (!redirect.isNull()) {
+            request.setAttribute(ATTR_ORIGIN, QVariant(redirect.origin()));
+            request.setAttribute(ATTR_LEVEL, QVariant(redirect.level()));
+        }
+#ifdef Q_WS_MAEMO_5
+        if (url.toString().startsWith("https://"))
+        {
+            QSslConfiguration configSsl = QSslConfiguration::defaultConfiguration();
+            configSsl.setProtocol(QSsl::AnyProtocol);
+            request.setSslConfiguration(configSsl);
+        }
+#endif
+        request.setRawHeader("User-Agent", USER_AGENT);
+        QNetworkReply *reply = _manager.get(request);
+        _currentDownloads.insert(url, reply);
 
 	return true;
 }
