@@ -5,7 +5,7 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QUrl>
-#include <QList>
+#include <QMap>
 #include <QSet>
 
 
@@ -39,15 +39,32 @@ private slots:
 	void downloadFinished(QNetworkReply *reply);
 
 private:
+	class Redirect
+	{
+	public:
+		Redirect() : _level(0) {}
+		Redirect(const QUrl &origin, int level) :
+		  _origin(origin), _level(level) {}
+
+		const QUrl &origin() const {return _origin;}
+		int level() const {return _level;}
+
+		bool isNull() const {return (_level == 0);}
+
+	private:
+		QUrl _origin;
+		int _level;
+	};
+
 	Downloader();
 	Downloader(Downloader const&);
 	void operator=(Downloader const&);
 
-	bool doDownload(const Download &dl);
+	bool doDownload(const Download &dl, const Redirect &redirect = Redirect());
 	bool saveToDisk(const QString &filename, QIODevice *data);
 
 	QNetworkAccessManager _manager;
-	QList<QNetworkReply *> _currentDownloads;
+	QMap<QUrl, QNetworkReply *> _currentDownloads;
 	QSet<QUrl> _errorDownloads;
 };
 
