@@ -21,6 +21,7 @@
 #include <QLocale>
 #include <QMimeData>
 #include <QUrl>
+#include <QDebug>
 #include "config.h"
 #include "icons.h"
 #include "keys.h"
@@ -62,10 +63,12 @@ GUI::GUI(QWidget *parent) : QMainWindow(parent)
 	createToolBars();
 
 	createBrowser();
-
 	QSplitter *splitter = new QSplitter();
 	splitter->setOrientation(Qt::Vertical);
 	splitter->setChildrenCollapsible(false);
+#ifdef Q_WS_MAEMO_5
+    splitter->setStyleSheet("QSplitter::handle:vertical {height: 0px;}");
+#endif
 	splitter->addWidget(_pathView);
 	splitter->addWidget(_graphTabWidget);
 	splitter->setContentsMargins(0, 0, 0, 0);
@@ -91,13 +94,21 @@ GUI::GUI(QWidget *parent) : QMainWindow(parent)
 	updatePathView();
 	updateStatusBarInfo();
 
-	readSettings();
 #ifdef Q_WS_MAEMO_5
     this->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, SIGNAL(customContextMenuRequested(const QPoint &)),
             this, SLOT(ShowContextMenu(const QPoint &)));
     grabZoomKeys(true);
+    /*sc_zoomin = new QShortcut(QKeySequence("F7"), NULL);
+    connect(sc_zoomin, SIGNAL(activated()), _pathView, SLOT(zoomin()));
+    sc_zoomout = new QShortcut(QKeySequence("F8"), NULL);
+    connect(sc_zoomout, SIGNAL(activated()), _pathView, SLOT(zoomout()));
+*/
+    //QShortcut* sc_zoomin = new QShortcut(QKeySequence("F7"), _pathView, SLOT(zoomin()), Qt::WindowShortcut);
+    connect(this, SIGNAL(s_zoom(QString)), _pathView, SLOT(zoom_maemo(QString)),Qt::UniqueConnection);
+    _showMapWidgetAction->setChecked(true);
 #endif
+    readSettings();
 }
 
 GUI::~GUI()
@@ -192,14 +203,16 @@ void GUI::ShowContextMenu(const QPoint &pos)
    QMenu* unitsmenu = contextMenu.addMenu( "units ->" );
    QMenu* xaxismenu = contextMenu.addMenu( "xaxis ->" );
    QMenu* mapsmenu = contextMenu.addMenu( "maps ->" );
+   //QMenu* poifilesmenu = contextMenu.addMenu( "pois ->" );
    xaxismenu->addAction(_distanceGraphAction);
    xaxismenu->addAction(_timeGraphAction);
    unitsmenu->addAction(_metricUnitsAction);
    unitsmenu->addAction(_imperialUnitsAction);
    mapsmenu->addActions(_mapActions);
+   //poifilesmenu->addActions(_poiFilesActions);
    contextMenu.addAction(_fullscreenAction);
    contextMenu.addAction(_showGraphsAction);
-
+   contextMenu.addAction(_showMapWidgetAction);
    contextMenu.exec(mapToGlobal(pos));
 }
 #endif
@@ -337,11 +350,13 @@ void GUI::createActions()
 	_openFileAction->setShortcut(OPEN_SHORTCUT);
 	connect(_openFileAction, SIGNAL(triggered()), this, SLOT(openFile()));
 	addAction(_openFileAction);
-	/*_printFileAction = new QAction(QIcon(QPixmap(PRINT_FILE_ICON)),
+#ifndef Q_WS_MAEMO_5
+    _printFileAction = new QAction(QIcon(QPixmap(PRINT_FILE_ICON)),
 	  tr("Print..."), this);
 	_printFileAction->setActionGroup(_fileActionGroup);
 	connect(_printFileAction, SIGNAL(triggered()), this, SLOT(printFile()));
-	addAction(_printFileAction);*/
+    addAction(_printFileAction);
+#endif
 	_exportFileAction = new QAction(QIcon(QPixmap(EXPORT_FILE_ICON)),
 	  tr("Export to PDF..."), this);
 	_exportFileAction->setShortcut(EXPORT_SHORTCUT);
@@ -441,6 +456,22 @@ void GUI::createActions()
 	connect(_showGraphsAction, SIGNAL(triggered(bool)), this,
 	  SLOT(showGraphs(bool)));
 	addAction(_showGraphsAction);
+#ifdef Q_WS_MAEMO_5
+    _showMapWidgetAction = new QAction(QIcon(QPixmap(SHOW_GRAPHS_ICON)),
+      tr("Show map widget"), this);
+    _showMapWidgetAction->setCheckable(true);
+    _showMapWidgetAction->setShortcut(SHOW_MAPWIDGET_SHORTCUT);
+    connect(_showMapWidgetAction, SIGNAL(triggered(bool)), this,
+      SLOT(showMapWidget(bool)));
+    addAction(_showMapWidgetAction);
+    _showStatusbarAction = new QAction(QIcon(QPixmap(SHOW_GRAPHS_ICON)),
+      tr("Show statusbar"), this);
+    _showStatusbarAction->setCheckable(true);
+    _showStatusbarAction->setShortcut(SHOW_STATUSBAR_SHORTCUT);
+    connect(_showStatusbarAction, SIGNAL(triggered(bool)), this,
+      SLOT(showStatusbar(bool)));
+    addAction(_showStatusbarAction);
+#endif
 	ag = new QActionGroup(this);
 	ag->setExclusive(true);
 	_distanceGraphAction = new QAction(tr("Distance"), this);
@@ -465,8 +496,14 @@ void GUI::createActions()
 	// Settings actions
 	_showToolbarsAction = new QAction(tr("Show toolbars"), this);
 	_showToolbarsAction->setCheckable(true);
+#ifdef Q_WS_MAEMO_5
+    _showToolbarsAction->setShortcut(SHOW_TOOLBARS_SHORTCUT);
+#endif
 	connect(_showToolbarsAction, SIGNAL(triggered(bool)), this,
 	  SLOT(showToolbars(bool)));
+#ifdef Q_WS_MAEMO_5
+    addAction(_showToolbarsAction);
+#endif
 	ag = new QActionGroup(this);
 	ag->setExclusive(true);
 	_metricUnitsAction = new QAction(tr("Metric"), this);
@@ -573,6 +610,7 @@ void GUI::createMenus()
 
     _mapMenu = menuBar()->addMenu(tr("Map"));
     _mapMenu->addAction(_showMapAction);
+    _mapMenu->addAction(_showMapWidgetAction);
     _mapMenu->addAction(_showGraphGridAction);
     _mapMenu->addAction(_showGraphsAction);
     _mapMenu->addAction(_showWaypointLabelsAction);
@@ -584,7 +622,8 @@ void GUI::createMenus()
     _mapMenu->menuAction()->setVisible(false);
     _mapMenu->addAction(_toggleMapMenu);
     _poiMenu = menuBar()->addMenu(tr("POI"));
-    //_poiFilesMenu->addActions(_poiFilesActions);
+    _poiFilesMenu = _poiMenu->addMenu(tr("POI files"));
+    _poiFilesMenu->addActions(_poiFilesActions);
     _poiMenu->addAction(_openPOIAction);
     _poiMenu->addAction(_closePOIAction);
     _poiMenu->addAction(_showPOILabelsAction);
@@ -784,11 +823,12 @@ void GUI::keys()
     msgBox.setWindowTitle(tr("Keyboard controls"));
     msgBox.setText(QString("<h3>") + tr("Keyboard controls") + QString("</h3>"));
     msgBox.setInformativeText(
-      QString("<div><table width=\"300\"><tr><td>") + tr("Next file")
+      QString("<div><table width=\"400\"><tr><td>") + tr("Next file")
       + QString("</td><td><i>RIGHT</i></td></tr><tr><td>") + tr("Previous file")
       + QString("</td><td><i>LEFT</i></td></tr><tr><td>")
       + tr("First file") + QString("</td><td><i>UP</i></td></tr><tr><td>")
       + tr("Last file") + QString("</td><td><i>DOWN</i></td></tr><tr><td>")
+      + tr("Zoom") + QString("</td><td><i>Vol.up/Vol.down</i></td></tr><tr><td>")
       + tr("Append modifier") + QString("</td><td><i>SHIFT</i></td></tr>"
       "<tr><td></td><td></td></tr><tr><td>")
       + tr("Next map") + QString("</td><td><i>")
@@ -805,8 +845,14 @@ void GUI::keys()
       + _showPOIAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
       + tr("Show Map") + QString("</td><td><i>")
       + _showMapAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
+      + tr("Show MapWidget") + QString("</td><td><i>")
+      + _showMapWidgetAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
       + tr("Show Graph") + QString("</td><td><i>")
       + _showGraphsAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
+      + tr("Show Statusbar") + QString("</td><td><i>")
+      + _showStatusbarAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
+      + tr("Show Toolbar") + QString("</td><td><i>")
+      + _showToolbarsAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
       + tr("Distance") + QString("</td><td><i>")
       + _distanceGraphAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
       + tr("Time") + QString("</td><td><i>")
@@ -944,7 +990,7 @@ bool GUI::loadFile(const QString &fileName)
 		updatePathView();
 
 		QString error = tr("Error loading data file:") + "\n\n"
-		  + fileName + "\n\n" + data.errorString();
+          + fileName + "\n\n" + data.errorString();
 		if (data.errorLine())
 			error.append("\n" + tr("Line: %1").arg(data.errorLine()));
 		QMessageBox::critical(this, APP_NAME, error);
@@ -980,7 +1026,7 @@ bool GUI::openPOIFile(const QString &fileName)
 		_showPOIAction->setChecked(true);
 		QAction *action = createPOIFileAction(_poi->files().indexOf(fileName));
 		action->setChecked(true);
-		_poiFilesMenu->addAction(action);
+        _poiFilesMenu->addAction(action);
 
 		return true;
 	}
@@ -1233,6 +1279,16 @@ void GUI::showMap(bool show)
 	else
 		_pathView->setMap(0);
 }
+#ifdef Q_WS_MAEMO_5
+void GUI::showMapWidget(bool show)
+{
+    _pathView->setHidden(!show);
+}
+#endif
+void GUI::showStatusbar(bool show)
+{
+    statusBar()->setHidden(!show);
+}
 
 void GUI::showGraphs(bool show)
 {
@@ -1269,6 +1325,11 @@ void GUI::showFullscreen(bool show)
 		showGraphs(false);
 		_showGraphsAction->setChecked(false);
 		_pathView->setFrameStyle(QFrame::NoFrame);
+#ifdef Q_WS_MAEMO_5
+        showStatusbar(false);
+        _showStatusbarAction->setChecked(false);
+        _showToolbarsAction->setChecked(false);
+#endif
 
 		showFullScreen();
 	} else {
@@ -1276,8 +1337,15 @@ void GUI::showFullscreen(bool show)
 #ifndef Q_WS_MAEMO_5
 		menuBar()->show();
 #endif
-		if (_showToolbarsAction->isChecked())
-			showToolbars(true);
+#ifdef Q_WS_MAEMO_5
+
+            showStatusbar(true);
+            _showStatusbarAction->setChecked(true);
+        _showToolbarsAction->setChecked(false);
+        showToolbars(false);
+#endif
+        //if (_showToolbarsAction->isChecked())
+            //showToolbars(true);
 		_showGraphsAction->setChecked(_showGraphs);
 		if (_showGraphsAction->isEnabled())
 			showGraphs(_showGraphs);
@@ -1322,7 +1390,7 @@ void GUI::clearMapCache()
 void GUI::updateStatusBarInfo()
 {
 	if (_files.count() == 0)
-		_fileNameLabel->setText(tr("No GPX files loaded"));
+		_fileNameLabel->setText(tr("No files loaded"));
 	else if (_files.count() == 1)
 		_fileNameLabel->setText(_files.at(0));
 	else
@@ -1522,8 +1590,8 @@ void GUI::first()
 
 void GUI::keyPressEvent(QKeyEvent *event)
 {
-	QString file;
-
+    QString file;
+    qDebug()<< "keyevent";
 	switch (event->key()) {
 		case PREV_KEY:
 			file = _browser->prev();
@@ -1537,16 +1605,34 @@ void GUI::keyPressEvent(QKeyEvent *event)
 		case LAST_KEY:
 			file = _browser->last();
 			break;
-
+        case Qt::Key_F7:
+        qDebug()<< "f7";
+            emit s_zoom("in");
+            break;
+        case Qt::Key_F8:
+            emit s_zoom("out");
+            break;
+        /*case Qt::Key_N:
+            if (_showMapWidgetAction->isChecked()) {
+                _showMapWidgetAction->setChecked(false);
+                showMapWidget(false);
+            }
+            else
+            {
+                _showMapWidgetAction->setChecked(true);
+                showMapWidget(true);
+            }
+            break;*/
 		case Qt::Key_Escape:
 			if (_fullscreenAction->isChecked()) {
 				_fullscreenAction->setChecked(false);
 				showFullscreen(false);
 			}
 			break;
+
 	}
 
-	if (!file.isNull()) {
+    if (!file.isNull()) {
 		if (!(event->modifiers() & MODIFIER))
 			closeFiles();
 		openFile(file);
@@ -1609,6 +1695,10 @@ void GUI::writeSettings()
 	if (_showToolbarsAction->isChecked() != SHOW_TOOLBARS_DEFAULT)
 		settings.setValue(SHOW_TOOLBARS_SETTING,
 		  _showToolbarsAction->isChecked());
+    if (_showStatusbarAction->isChecked() != SHOW_STATUSBAR_DEFAULT)
+        settings.setValue(SHOW_STATUSBAR_SETTING,
+          _showStatusbarAction->isChecked());
+    settings.setValue("lastfile",_files.at(0));
 	settings.endGroup();
 
 	settings.beginGroup(MAP_SETTINGS_GROUP);
@@ -1722,6 +1812,7 @@ void GUI::writeSettings()
 
 void GUI::readSettings()
 {
+    QString lastfile;
 	QSettings settings(APP_NAME, APP_NAME);
 
 	settings.beginGroup(WINDOW_SETTINGS_GROUP);
@@ -1741,6 +1832,11 @@ void GUI::readSettings()
 		showToolbars(false);
 	else
 		_showToolbarsAction->setChecked(true);
+    if (!settings.value(SHOW_STATUSBAR_SETTING, SHOW_STATUSBAR_DEFAULT).toBool())
+        showStatusbar(false);
+    else
+        _showStatusbarAction->setChecked(true);
+    lastfile=settings.value("lastfile").toString();
 	settings.endGroup();
 
 	settings.beginGroup(MAP_SETTINGS_GROUP);
@@ -1907,6 +2003,7 @@ void GUI::readSettings()
 	_poi->setRadius(_options.poiRadius);
 
 	settings.endGroup();
+    if (lastfile!=" " && lastfile!="") openFile(lastfile);
 }
 
 int GUI::mapIndex(const QString &name)
