@@ -1,6 +1,5 @@
 #ifndef GUI_H
 #define GUI_H
-
 #include <QMainWindow>
 #include <QString>
 #include <QList>
@@ -45,6 +44,7 @@ private slots:
     void ShowContextMenu(const QPoint &pos);
     void createPoiMenu();
     void createMapMenu();
+    void showMapWidget(bool show);
 #endif
 	void about();
 	void keys();
@@ -59,6 +59,7 @@ private slots:
 	void openPOIFile();
 	void closePOIFiles();
 	void showMap(bool show);
+    void showStatusbar(bool show);
 	void showGraphs(bool show);
 	void showGraphGrids(bool show);
 	void showToolbars(bool show);
@@ -102,7 +103,6 @@ private:
 	void loadPOIs();
 	void closeFiles();
 	void plot(QPrinter *printer);
-
 	QAction *createPOIFileAction(int index);
 	void createPOIFilesActions();
 	void createMapActions();
@@ -177,6 +177,8 @@ private:
 	QAction *_imperialUnitsAction;
 	QAction *_nextMapAction;
 	QAction *_prevMapAction;
+    QAction *_showMapWidgetAction;
+    QAction *_showStatusbarAction;
 	QAction *_showTracksAction;
 	QAction *_showRoutesAction;
 	QAction *_showWaypointsAction;
@@ -219,6 +221,8 @@ private:
 
 	Export _export;
 	Options _options;
+signals:
+    void s_zoom(QString direction);
 };
 
 #endif // GUI_H
