@@ -2,6 +2,7 @@
 #include <QGraphicsScene>
 #include <QWheelEvent>
 #include <QSysInfo>
+#include <QDebug>
 #include "opengl.h"
 #include "rd.h"
 #include "wgs84.h"
@@ -285,7 +286,7 @@ QPointF PathView::contentsCenter() const
 void PathView::updatePOIVisibility()
 {
 	QHash<Waypoint, WaypointItem*>::const_iterator it, jt;
-
+    qDebug()<<"updatevis" << _showPOI;
 	if (!_showPOI)
 		return;
 
@@ -352,6 +353,7 @@ void PathView::setPOI(POI *poi)
 
 void PathView::updatePOI()
 {
+    qDebug() << "update poi";
 	QHash<Waypoint, WaypointItem*>::const_iterator it;
 
 	for (it = _pois.constBegin(); it != _pois.constEnd(); it++) {
@@ -374,7 +376,8 @@ void PathView::updatePOI()
 
 void PathView::addPOI(const QVector<Waypoint> &waypoints)
 {
-	qreal scale = mapScale(_zoom);
+    qDebug()<<"add Poi " << waypoints.size();
+    qreal scale = mapScale(_zoom);
 
 	for (int i = 0; i < waypoints.size(); i++) {
 		const Waypoint &w = waypoints.at(i);
@@ -388,7 +391,7 @@ void PathView::addPOI(const QVector<Waypoint> &waypoints)
 		pi->showLabel(_showPOILabels);
 		pi->setVisible(_showPOI);
 		_scene->addItem(pi);
-
+        qDebug()<< "pi" << pi << scale;
 		_pois.insert(w, pi);
 	}
 }
@@ -478,6 +481,14 @@ void PathView::mousePressEvent(QMouseEvent *e)
     else
         QGraphicsView::mousePressEvent(e);
 }
+void PathView::zoom_maemo(QString direction)
+{
+    qDebug()<< "zoomm" << direction;
+    int z = -1;
+    if (direction=="in") z = qMin(_zoom + 1, ZOOM_MAX);
+    else z = qMax(_zoom - 1, ZOOM_MIN);
+    if (z >= 0) zoom(z, QRect(QPoint(), size()).center());
+}
 #endif
 
 void PathView::keyPressEvent(QKeyEvent *event)
@@ -487,19 +498,22 @@ void PathView::keyPressEvent(QKeyEvent *event)
 #ifdef Q_WS_MAEMO_5
     if (event->key()==Qt::Key_F7)
         z = qMin(_zoom + 1, ZOOM_MAX);
-    if (event->key()==Qt::Key_F8)
+    else if (event->key()==Qt::Key_F8)
         z = qMax(_zoom - 1, ZOOM_MIN);
+    else QWidget::keyPressEvent(event);
+    if (z >= 0)
+        zoom(z, QRect(QPoint(), size()).center());
 #else
 	if (event->matches(QKeySequence::ZoomIn))
 		z = qMin(_zoom + 1, ZOOM_MAX);
 	if (event->matches(QKeySequence::ZoomOut))
 		z = qMax(_zoom - 1, ZOOM_MIN);
 
-#endif
 	if (z >= 0)
 		zoom(z, QRect(QPoint(), size()).center());
 	else
 		QWidget::keyPressEvent(event);
+#endif
 }
 
 void PathView::plot(QPainter *painter, const QRectF &target)
