@@ -14,7 +14,9 @@
 #define UNITS_SETTING                     "units"
 #define UNITS_DEFAULT                     (IMPERIAL_UNITS() ? Imperial : Metric)
 #define SHOW_TOOLBARS_SETTING             "toolbar"
-#define SHOW_TOOLBARS_DEFAULT             true
+#define SHOW_TOOLBARS_DEFAULT             false
+#define SHOW_STATUSBAR_SETTING             "statusbar"
+#define SHOW_STATUSBAR_DEFAULT             true
 
 #define GRAPH_SETTINGS_GROUP              "Graph"
 #define SHOW_GRAPHS_SETTING               "show"
